@@ -6,7 +6,7 @@
  This file helps you generate the POT file that contains all of the translatable
  strings / text in OpenShot.  Because some of our text is in custom XML files,
  the xgettext command can't correctly generate the POT file.  Thus... the 
- existance of this file. =)
+ existence of this file. =)
 
  Command to create the individual language PO files (Ascii files)
 		$ msginit --input=OpenShot.pot --locale=fr_FR
@@ -28,7 +28,7 @@
 
  @section LICENSE
  
- Copyright (c) 2008-2016 OpenShot Studios, LLC
+ Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
@@ -118,7 +118,7 @@ output.close()
 shutil.copy(os.path.join(langage_folder_path, "clean.po"), os.path.join(langage_folder_path, 'OpenShot_QtUi.pot'))
 os.remove(os.path.join(langage_folder_path, "clean.po"))
 
-# Remove duplciates (if any found)
+# Remove duplicates (if any found)
 subprocess.call('msguniq %s --use-first -o %s' % (os.path.join(langage_folder_path, 'OpenShot_QtUi.pot'),
                                       os.path.join(langage_folder_path, 'clean.po')), shell=True)
 shutil.copy(os.path.join(langage_folder_path, "clean.po"), os.path.join(langage_folder_path, 'OpenShot_QtUi.pot'))
@@ -172,9 +172,9 @@ for file in os.listdir(effects_path):
                 effects_text[param.attributes["title"].value] = full_file_path
 
 # Append on properties from libopenshot
-objects = [openshot.Clip(), openshot.Blur(), openshot.Brightness(),
-           openshot.ChromaKey(), openshot.Deinterlace(), openshot.Mask(),
-           openshot.Negate(), openshot.Saturation()]
+objects = [openshot.Clip(), openshot.Bars(), openshot.Blur(), openshot.Brightness(),
+           openshot.ChromaKey(), openshot.ColorShift(), openshot.Crop(), openshot.Deinterlace(), openshot.Hue(), openshot.Mask(),
+           openshot.Negate(), openshot.Pixelate(), openshot.Saturation(), openshot.Shift(), openshot.Wave()]
 
 # Loop through each libopenshot object
 for object in objects:
